==> iaxmodem_1.1.1~dfsg.orig.tar.gz: iaxmodem-1.1.1/lib/spandsp/src/v17tx_floating_rrc.h <==
#define PULSESHAPER_GAIN        1.000000f
#define PULSESHAPER_COEFF_SETS  10
static const float pulseshaper[PULSESHAPER_COEFF_SETS][9] =
{
    {
          -0.0028949651f,     /* Filter 0 */
          -0.0180558826f,
           0.0644370007f,
          -0.1680546408f,
           0.6136031185f,
           0.6136031185f,
          -0.1680546408f,
           0.0644370007f,
          -0.0180558826f
    },
    {
           0.0031457252f,     /* Filter 1 */
          -0.0296755127f,
           0.0821537989f,
          -0.1948071639f,
           0.7563219340f,
           0.4608861696f,
          -0.1273859874f,
           0.0418434527f,
          -0.0059021756f
    },
    {
           0.0095859914f,     /* Filter 2 */
          -0.0389394461f,
           0.0918555164f,
          -0.2016880165f,
           0.8793516522f,
           0.3081344924f,
          -0.0792085168f,
           0.0176601547f,
           0.0051283313f
    },
    {
           0.0153896886f,     /* Filter 3 */
          -0.0441001627f,
           0.0909724632f,
          -0.1838386257f,
           0.9741012232f,
           0.1647552896f,
          -0.0297442695f,
          -0.0050682351f,
           0.0137350965f
    },
    {
           0.0194884074f,     /* Filter 4 */
          -0.0437412555f,
           0.0779044290f,
          -0.1380831525f,
           1.0338273601f,
           0.0388498601f,
           0.0155354866f,
          -0.0238603903f,
           0.0191007897f
    },
    {
           0.0209425254f,     /* Filter 5 */
          -0.0370198705f,
           0.0523524598f,
          -0.0633894611f,
           1.0542286928f,
          -0.0633894611f,
           0.0523524598f,
          -0.0370198705f,
           0.0209425254f
    },
    {
           0.0191007897f,     /* Filter 6 */
          -0.0238603903f,
           0.0155354866f,
           0.0388498602f,
           1.0338273601f,
          -0.1380831525f,
           0.0779044290f,
          -0.0437412555f,
           0.0194884074f
    },
    {
           0.0137350965f,     /* Filter 7 */
          -0.0050682351f,
          -0.0297442695f,
           0.1647552896f,
           0.9741012231f,
          -0.1838386257f,
           0.0909724632f,
          -0.0441001627f,
           0.0153896885f
    },
    {
           0.0051283313f,     /* Filter 8 */
           0.0176601547f,
          -0.0792085168f,
           0.3081344925f,
           0.8793516522f,
          -0.2016880165f,
           0.0918555164f,
          -0.0389394461f,
           0.0095859914f
    },
    {
          -0.0059021756f,     /* Filter 9 */
           0.0418434528f,
          -0.1273859874f,
           0.4608861697f,
           0.7563219340f,
          -0.1948071639f,
           0.0821537989f,
          -0.0296755127f,
           0.0031457252f
    }
};

==> iaxmodem_1.2.0~dfsg.orig.tar.gz: iaxmodem-1.2.0/lib/spandsp/src/v17tx_floating_rrc.h <==
#define TX_PULSESHAPER_GAIN        1.000000f
#define TX_PULSESHAPER_COEFF_SETS  10
static const float tx_pulseshaper[TX_PULSESHAPER_COEFF_SETS][9] =
{
    {
          -0.0028949651f,     /* Filter 0 */
          -0.0180558826f,
           0.0644370007f,
          -0.1680546408f,
           0.6136031185f,
           0.6136031185f,
          -0.1680546408f,
           0.0644370007f,
          -0.0180558826f
    },
    {
           0.0031457252f,     /* Filter 1 */
          -0.0296755127f,
           0.0821537989f,
          -0.1948071639f,
           0.7563219340f,
           0.4608861696f,
          -0.1273859874f,
           0.0418434527f,
          -0.0059021756f
    },
    {
           0.0095859914f,     /* Filter 2 */
          -0.0389394461f,
           0.0918555164f,
          -0.2016880165f,
           0.8793516522f,
           0.3081344924f,
          -0.0792085168f,
           0.0176601547f,
           0.0051283313f
    },
    {
           0.0153896886f,     /* Filter 3 */
          -0.0441001627f,
           0.0909724632f,
          -0.1838386257f,
           0.9741012232f,
           0.1647552896f,
          -0.0297442695f,
          -0.0050682351f,
           0.0137350965f
    },
    {
           0.0194884074f,     /* Filter 4 */
          -0.0437412555f,
           0.0779044290f,
          -0.1380831525f,
           1.0338273601f,
           0.0388498601f,
           0.0155354866f,
          -0.0238603903f,
           0.0191007897f
    },
    {
           0.0209425254f,     /* Filter 5 */
          -0.0370198705f,
           0.0523524598f,
          -0.0633894611f,
           1.0542286928f,
          -0.0633894611f,
           0.0523524598f,
          -0.0370198705f,
           0.0209425254f
    },
    {
           0.0191007897f,     /* Filter 6 */
          -0.0238603903f,
           0.0155354866f,
           0.0388498602f,
           1.0338273601f,
          -0.1380831525f,
           0.0779044290f,
          -0.0437412555f,
           0.0194884074f
    },
    {
           0.0137350965f,     /* Filter 7 */
          -0.0050682351f,
          -0.0297442695f,
           0.1647552896f,
           0.9741012231f,
          -0.1838386257f,
           0.0909724632f,
          -0.0441001627f,
           0.0153896885f
    },
    {
           0.0051283313f,     /* Filter 8 */
           0.0176601547f,
          -0.0792085168f,
           0.3081344925f,
           0.8793516522f,
          -0.2016880165f,
           0.0918555164f,
          -0.0389394461f,
           0.0095859914f
    },
    {
          -0.0059021756f,     /* Filter 9 */
           0.0418434528f,
          -0.1273859874f,
           0.4608861697f,
           0.7563219340f,
          -0.1948071639f,
           0.0821537989f,
          -0.0296755127f,
           0.0031457252f
    }
};
